@@ -300,14 +300,27 @@ class cmd():
             print('VOL            Отображает метку и серийный номер тома для диска.')
             print('XCOPY          Копирует файлы и деревья папок.')
             print('WMIC           Отображает сведения об инструментарии WMI в интерактивной командной оболочке.')
+        if a == 'stop':
+            exit()
     def start_command():
         a = input('       ')
         if a == 'start':
             import os
             a = input('       ')
             os.system(a)
+        if a == 'stop':
+            exit()
     def cmd():
         import os
         a = input('       ')
         if a == "start":
-            os.startfile('cmd')
\ No newline at end of file
+            os.startfile('cmd')
+        if a == 'stop':
+            exit()
+    def cd():
+        if a == 'start':
+            import os
+            a = input('       ')
+            os.system('cd' + a)
+        if a == 'stop':
+            exit()
\ No newline at end of file
